// This class is used for establishing communication with the eb500 bluetooth dongle on the robot.

import java.io.*;
import javax.bluetooth.*;
import javax.microedition.io.*;
import java.util.LinkedList;

public class BluetoothServer extends BluetoothComm {
	protected RobotTracker 				rb;					// Reference to the main program
    private StreamConnection 			connection;			// The connection stream from the pc to the robot
	private StreamConnectionNotifier 	streamConnNotifier;
    private InputStream 				in;					// The stream to read bluetooth data from the robot
   	private OutputStream 				out;				// The stream to write bluetooth data to the robot

    public BluetoothServer(RobotTracker mainApp) {
    	super(mainApp);
    	rb = mainApp;
    	queue = new LinkedList<int[]>();
    }

    // Start running the server and await for a connection from the robot.
    public void startServer() throws Exception {
 		try {
		    startListening(in, out);
		    try {
		    	streamConnNotifier.close();
		    } catch (NullPointerException e){}
	    } catch (InterruptedIOException e) {
 		} catch (IOException e) {
 		}
    }



    // Start running the bluetooth server and attempt to connect to the robot through bluetooth.
    public boolean connectToRobot() {
 		try {
		    // Create a UUID for SPP
		    UUID uuid = new UUID("1101", true);
		    // Create the servicve url
		    String connectionString = "btspp://localhost:" + uuid + ";name=RBCServer";

		    // Open server url
		    streamConnNotifier = (StreamConnectionNotifier)Connector.open( connectionString );

		    // Wait for client connection
			rb.showRobotDisconnected();
		    connection=streamConnNotifier.acceptAndOpen();

		    RemoteDevice dev = RemoteDevice.getRemoteDevice(connection);
		    dev.getBluetoothAddress();
		    dev.getFriendlyName(true);
			rb.showRobotConnected();

		   	out = connection.openOutputStream();
		    in = connection.openInputStream();
	    } catch (InterruptedIOException e) {
	    	return false;
 		} catch (IOException e) {
 			return false;
 		}
 		return true;
    }
}
