// This class is used for establishing communication with the Easy Bluetooth dongle on the robot.

import java.io.*;
import java.awt.Color;
import javax.microedition.io.*;
import java.util.LinkedList;

public class BluetoothServerEasyBlue extends BluetoothComm {
	private String 				blueURL;			// Bluetooth address of the robot
	private RobotTracker 		rb;					// Reference to the main program
    private StreamConnection 	connection;			// The connection stream from the pc to the robot
    private InputStream 		in;					// The stream to read bluetooth data from the robot
   	private OutputStream 		out;				// The stream to write bluetooth data to the robot

    public BluetoothServerEasyBlue(RobotTracker mainApp) {
    	super(mainApp);
    	rb = mainApp;
    	queue = new LinkedList<int[]>();
    }

    // Set the URL of the bluetooth device to connect to.
	public void setURL(String url) {
   		blueURL = url;
	}

    // Start running the bluetooth server and attempt to connect to the robot through bluetooth.
    public boolean connectToRobot() {
    	connection = null;
 		try {
		    // Create the servicve url
		    String connectionString = blueURL;

		    // Open server url (i.e., establish a connection with the robot's bluetooth device)
		    rb.showRobotConnecting();
		    System.out.println("Connecting to robot ...");
		    closeEverything();

		    connection = (StreamConnection)Connector.open(connectionString);
   			out = connection.openOutputStream();
		    in = connection.openInputStream();

			// Send request to the robot for a connection
		    out.write(RBCConstants.REQUEST_CONNECTION);
	        out.flush();
System.out.println("Waiting for ACK ...");
	        // Wait for acknowledgement from the robot
	        int ack = -1;
	        long	startTime = new java.util.Date().getTime();
	       	while (ack != RBCConstants.ROBOT_CONN_ACK) {
	       		if (in.available()>0)
	       			ack = in.read();
	       		try {
	        		Thread.sleep(0);
	        	} catch (InterruptedException e) {
	        		Thread.currentThread().interrupt();
	        		break;
	        	}
	        	// Check if timeout
	        	if ((new java.util.Date().getTime() - startTime) > 5000) {
	        		throw new IOException();
	        	}
	       	}
System.out.println("Got it ...");
	       	return true;
	    } catch (InterruptedIOException e) {
	    	closeEverything();
	    	return false;
 		} catch (IOException e) {
 			System.out.println(e.getMessage());
		    rb.updateStatusBar("Unable to Connect to Robot", Color.black);
		    System.out.println("Unable to Connect to Robot");
			rb.showRobotDisconnected();
			closeEverything();
 			return false;
 		}
    }

	// Close down everything .. all streams and the connection
	private void closeEverything() {
	   	// free up I/O streams and close the socket connection
      	try {
        	if (in != null)
          		in.close();
      	} catch (Exception ignored) {}
      	try {
        	if (out != null)
          		out.close();
      	} catch (Exception ignored) {}
      	try {
        	if (out != null)
          		out.close();
      	} catch (Exception ignored) {}
      	try {
        	if (in != null)
          		in.close();
      	} catch (Exception ignored) {}
      	try {
       		if (connection != null)
          		connection.close();
      	} catch (Exception ignored) {}
	}

    // Send a begin command to the robot and then go into infinite loop mode
    public void startServer() throws Exception {
 		try {
   			// Instruct the robot to begin now
	    	out.write(RBCConstants.ROBOT_BEGIN);
	    	out.flush();

			// Now go into the infinite loop to do communications, return when server stopped or interrupted
		    startListening(in, out);

		    // All done, close the connection
		    closeEverything();
		    rb.showRobotDisconnected();
	    } catch (InterruptedIOException e) {
	    	closeEverything();
	    	rb.showRobotDisconnected();
 		} catch (IOException e) {
		    rb.updateStatusBar("Unable to Start Robot", Color.black);
		    System.out.println("Unable to Start Robot");
			closeEverything();
			rb.showRobotDisconnected();
 		}
    }
}
